@@ -43,10 +43,11 @@ class Tk:
         self.window = Frame(parent=self, parent_frame=self.canvas)
         self.window.pack()
         self.canvas.create_window((0,0), window=self.window.tkinter, anchor='nw')
+        self.components = []
 
 
-    def configure_scrollbar(x_scroll, y_scroll):
-        container = tk.Frame(TK)
+    def configure_scrollbar(self, x_scroll, y_scroll):
+        container = tk.Frame(self.root)
         container.pack(fill=tk.BOTH, expand=1)
 
         canvas = tk.Canvas(container)
@@ -69,7 +70,7 @@ class Tk:
             x_scrollbar.pack(side=tk.BOTTOM, fill=tk.X)
             canvas.configure(xscrollcommand=x_scrollbar.set)
 
-        canvas.pack(side=tk.LEFT, fill=tk.BOTH, expane=1)
+        canvas.pack(side=tk.LEFT, fill=tk.BOTH, expand=1)
         canvas.bind(
             '<Configure>',
             lambda e: canvas.configure(scrollregion=canvas.bbox('all'))
@@ -77,13 +78,54 @@ class Tk:
 
         return canvas
 
+        
+    def update(self):
+        self.canvas.update_idletasks()
+        self.canvas.configure(
+            scrollregion=self.canvas.bbox('all')
+        )
+
+
+    def add_component(
+        self,
+        component_class,
+        parent_frame=None,
+        parent=None,
+        **kwargs
+    ):
+        if parent is not None:
+            parent = parent 
+        else:
+            parent = self
+        if parent_frame is not None:
+            parent_frame = parent_frame
+        else:
+            parent_frame = self.window.tkinter
+        for c in COMPONENTS:
+            if issubclass(component_class, c):
+                component = component_class(parent=parent, parent_frame=parent_frame, fill=FILL['both'], **kwargs)
+                self.components.append(component)
+                return component
+        raise ValueError(f'Invalid Component Class passed to {self} during add_component call')
+
+
+    def pack(self):
+        for component in self.components:
+            component.pack()
+
+
+    def mainloop(self):
+        self.root.mainloop()
+
 
 class Component:
     def __init__(
         self,
         parent,
-        parent_frame=None,
-        fill='both'
+        fill='both',
+        padx=0,
+        pady=0,
+        parent_frame=None
     ):
         self.parent = parent
         self.parent_frame = parent_frame if parent_frame else parent.tkinter
@@ -93,6 +135,8 @@ class Component:
             self.fill = FILL[fill]
         else:
             self.fill = fill
+        self.padx = padx
+        self.pady = pady
 
 
     def add_var(self, data_type, default=None):
@@ -136,7 +180,7 @@ class Component:
                 sticky=self.fill['sticky']
             )
         else:
-            self.tkinter.pack(fill=self.fill['fill'])
+            self.tkinter.pack(fill=self.fill['fill'], padx=self.padx, pady=self.pady)
 
 
     def destroy(self):
@@ -152,8 +196,11 @@ class Frame(Component):
         grid_children=False,
         max_columns=None,
         update_func=None,
+        padding=['left', 'top', 'right', 'bottom'], # in int
+        fill='both',
+        padx=0,
+        pady=0,
         parent_frame=None,
-        fill='both'
     ):
         super().__init__(
             parent,
@@ -178,11 +225,13 @@ class Frame(Component):
             parent=None,
             **kwargs
     ):
-
-        parent = parent if parent is not None else self
-        component = component_class(parent=parent, fill=self.fill_children, **kwargs)
-        self.components.append(component)
-        return component
+        for c in COMPONENTS:
+            if issubclass(component_class, c):
+                parent = parent if parent is not None else self
+                component = component_class(parent=parent, fill=self.fill_children, **kwargs)
+                self.components.append(component)
+                return component
+        raise ValueError(f'Invalid Component Class passed to {self} during add_component call')
 
 
     def update(self):
@@ -238,8 +287,8 @@ class Button(Component):
         parent,
         text,
         command,
-        parent_frame=None,
-        fill='both'
+        fill='both',
+        parent_frame=None
     ):
         super().__init__(
             parent,
@@ -247,7 +296,7 @@ class Button(Component):
             fill
         )
 
-        self.tkinter = tk.Button(
+        self.tkinter = ttk.Button(
             self.parent_frame,
             text=text,
             command=command
@@ -273,21 +322,21 @@ class Label(Component):
         self,
         parent,
         text,
-        parent_frame=None,
-        fill='both'
+        fill='both',
+        parent_frame=None
     ):
         super().__init__(
-            parent,
-            parent_frame,
-            fill
+            parent=parent,
+            fill=fill,
+            parent_frame=parent_frame
         )
 
-        self.tkinter = tk.Label(
+        self.tkinter = ttk.Label(
             self.parent_frame,
-            text=text
+            text=text,
         )
 
-    
+
     @property
     def text(self):
         return self.tkinter.cget('text')
@@ -303,13 +352,13 @@ class Entry(Component):
         self,
         parent,
         default=None,
-        parent_frame=None,
-        fill='both'
+        fill='both',
+        parent_frame=None
     ):
         super().__init__(
-            parent,
-            parent_frame,
-            fill
+            parent=parent,
+            fill=fill,
+            parent_frame=parent_frame
         )
 
         self.tkinter = ttk.Entry(
@@ -344,19 +393,19 @@ class CheckButton(Component):
         values=[False, True],
         command=None,
         custom_trace=None,
-        parent_frame=None,
-        fill='both'
+        fill='both',
+        parent_frame=None
     ):
         super().__init__(
-            parent,
-            parent_frame,
-            fill
+            parent=parent,
+            fill=fill,
+            parent_frame=parent_frame
         )
 
         self._active = self.add_var('bool')
         self._value = self.add_var(data_type)
 
-        self.tkinter = tk.Checkbutton(
+        self.tkinter = ttk.Checkbutton(
             self.parent_frame,
             text=text,
             variable=self._active,
@@ -430,9 +479,9 @@ class RadioButton(Component):
         fill='both'
     ):
         super().__init__(
-            parent,
-            parent_frame,
-            fill
+            parent=parent,
+            fill=fill,
+            parent_frame=parent_frame
         )
 
         if not variable:
@@ -449,7 +498,7 @@ class RadioButton(Component):
         else:
             self._selection = value
         
-        self.tkinter = tk.Radiobutton(
+        self.tkinter = ttk.Radiobutton(
             self.parent_frame,
             text=text,
             variable=self._value,
@@ -491,7 +540,7 @@ class OptionMenu(Component):
         else:
             self._value = self.add_var('str')
 
-        self.tkinter = tk.OptionMenu(
+        self.tkinter = ttk.OptionMenu(
             self.parent_frame,
             variable=self._value,
             value=default
@@ -570,7 +619,7 @@ class RadioMenu(Frame):
         if isinstance(options, list):
             for text in options:
                 self.add_component(
-                    'radio_button',
+                    RadioButton,
                     text=text,
                     variable=self._value,
                     value=text
@@ -578,7 +627,7 @@ class RadioMenu(Frame):
         else:
             for text, value in options.items():
                 self.add_component(
-                    'radio_button',
+                    RadioButton,
                     text=text,
                     data_type=self.data_type,
                     value=value
@@ -628,11 +677,11 @@ class LabeledOption(Frame):
             self._value = self.add_var('str')
 
         self.label = self.add_component(
-            'label',
+            Label,
             text=text
         )
         self.menu = self.add_component(
-            'option_menu',
+            OptionMenu,
             variable=self._value,
             options=options,
             default=default
@@ -683,11 +732,11 @@ class LabeledEntry(Frame):
         )
         
         self.label = self.add_component(
-            'label',
+            Label,
             text=text
         )
         self.entry = self.add_component(
-            'entry',
+            Entry,
             default=default
         )
 
@@ -728,14 +777,14 @@ class ButtonMatrix(Frame):
         if isinstance(buttons, list):
             for text in buttons:
                 self.add_component(
-                    'button',
+                    Button,
                     text=text,
                     command=self._pass
                 )
         else:
             for text, command in buttons.items():
                 self.add_component(
-                    'button',
+                    Button,
                     text=text,
                     command=command
                 )
@@ -821,18 +870,17 @@ class DynamicComponentFrame(Frame):
         super().destroy()
 
 
-COMPONENTS = {
-    'button': Button,
-    'check_button': CheckButton,
-    'radio_button': RadioButton,
-    'option_menu': OptionMenu,
-    'label': Label,
-    'entry': Entry,
-    'frame': Frame,
-    'radio_menu': RadioMenu,
-    'labeled_entry': LabeledEntry,
-    'button_matrix': ButtonMatrix,
-    'dynamic_component_frame': DynamicComponentFrame,
-    'labeled_option': LabeledOption
-}
-
+COMPONENTS = [
+    Button,
+    CheckButton,
+    RadioButton,
+    OptionMenu,
+    Label,
+    Entry,
+    Frame,
+    RadioMenu,
+    LabeledEntry,
+    ButtonMatrix,
+    DynamicComponentFrame,
+    LabeledOption
+]
